import { Browser, Metrics } from 'puppeteer';
import { Scenarios, ScenarioConfig } from '../flamegrill';
export interface Profile {
    logFile: string;
    metrics: Metrics;
}
export interface ScenarioProfile extends Profile {
    baseline?: Profile;
}
export interface ScenarioProfiles {
    [scenarioName: string]: ScenarioProfile;
}
/**
 * Profiles scenarios and generates profile (V8) logs.
 *
 * @param config
 * @param scenarios
 */
export declare function profile(scenarios: Scenarios, config: Required<ScenarioConfig>): Promise<ScenarioProfiles>;
/**
 * Run profiler against provided URL and return resulting profiler output.
 *
 * @param {*} browser Launched puppeteer instance.
 * @param {string} testUrl Base URL supporting 'scenario' and 'iterations' query parameters.
 * @param {string} profileName Name of scenario that will be used with baseUrl.
 * @param {string} logDir Absolute path to output log profiles.
 * @returns {string} Log file path associated with test.
 */
declare function profileUrl(browser: Browser, testUrl: string, profileName: string, logDir: string): Promise<Profile>;
export declare const __unitTestHooks: {
    profileUrl: typeof profileUrl;
};
export {};
//# sourceMappingURL=profile.d.ts.map